/*
 * Copyright (C) 2012 Giorgio Vazzana
 *
 * This file is part of parole-conference.
 *
 * parole-conference is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * parole-conference is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include "nc.h"

void die(char *msg, int exit_code)
{
	/* shut down ncurses */
	endwin();

	if (msg) {
		fprintf(fplog,  "%s", msg);
		fprintf(stderr, "%s", msg);
	} else {
		fprintf(stderr, "An error occured, please check file '%s' for more info.\n", LOGFILE);
	}
	exit(exit_code);
}

void log_msg(char *msg)
{
	if (msg) {
		fprintf(fplog, "%s", msg);
		fflush(fplog);
	}
}

void print_msg(char *msg)
{
	int y, x;

	log_msg(msg);

	getyx(stdscr, y, x);
	wprintw(nctx.win, "%s", msg);
	wrefresh(nctx.win);
	move(y, x);
	refresh();
}

void print_bars(char *version)
{
	/* title bar */
	move(0, 0);
	printw(" parole-conference, ver. %s", version);
	move(0, 0);
	chgat(-1, A_NORMAL, 1, NULL);

	/* status bar */
	move(nctx.rows - 2, 0);
	addch(' ');
	move(nctx.rows - 2, 0);
	chgat(-1, A_NORMAL, 1, NULL);

	refresh();
}

void print_prompt(char *nick)
{
	move(nctx.rows - 1, 0);
	printw("%s> ", nick);
	refresh();
}

void clear_input_line()
{
	nctx.linepos = 0;
	nctx.nchars  = 0;
	move(nctx.rows - 1, 0);
	clrtoeol();
	refresh();
}
