/*
 * Copyright (C) 2012 Giorgio Vazzana
 *
 * This file is part of parole-conference.
 *
 * parole-conference is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * parole-conference is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NETWORK_H
#define NETWORK_H

#include "parole-conference.h"

#define RES_ERROR      -1
#define RES_OK          0
#define RES_REFUSED     1
#define RES_NEED_ANSWER 2

int resolve_address(struct sockaddr_in *addr, char *host, int port);
void send_udp_packet(int sockfd, struct udp_packet_st *udp_packet);
void receive_udp_packet(int sockfd, struct udp_packet_st *udp_packet);

int node_get_count(struct node *nodes[]);
int node_search(struct node *nodes[], struct sockaddr_in addr);
void node_delete(struct node *nodes[], int idx, int for_timeout, struct tone *tone);
int node_add(struct node *nodes[], struct sockaddr_in addr, const char *nick, struct tone *tone);

void packet_call(struct udp_packet_st *udp_packet, char *nick);
void packet_refuse(struct udp_packet_st *udp_packet);
void packet_table(struct udp_packet_st *udp_packet, char *nick, struct node *nodes[], int exclude_idx);
void packet_audio(struct udp_packet_st *udp_packet, uint32_t sequence_number, uint8_t *payload, size_t payloadlen);
void packet_chat(struct udp_packet_st *udp_packet, char *buf, size_t len);
void packet_nop(struct udp_packet_st *udp_packet);
void packet_end(struct udp_packet_st *udp_packet);

void send_packet_to_all(struct node *nodes[], int sockfd, struct udp_packet_st *udp_packet, size_t *bytes_sent);
void call_new_nodes(struct node *nodes[], int sockfd, char *nick, int use_relay);

int process_packet(struct PContext *pctx, struct udp_packet_st *udp_packet);

#endif
