/*
 * Copyright (C) 2012 Giorgio Vazzana
 *
 * This file is part of parole.
 *
 * parole is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * parole is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "rw.h"

/* write functions, be */

void write_be64(uint8_t *p, uint64_t v)
{
	p[0] = (v >> 56);
	p[1] = (v >> 48);
	p[2] = (v >> 40);
	p[3] = (v >> 32);
	p[4] = (v >> 24);
	p[5] = (v >> 16);
	p[6] = (v >>  8);
	p[7] = (v      );
}

void write_be32(uint8_t *p, uint32_t v)
{
	p[0] = (v >> 24);
	p[1] = (v >> 16);
	p[2] = (v >>  8);
	p[3] = (v      );
}

void write_be16(uint8_t *p, uint16_t v)
{
	p[0] = (v >>  8);
	p[1] = (v      );
}

/* write functions, le */

void write_le64(uint8_t *p, uint64_t v)
{
	p[0] = (v      );
	p[1] = (v >>  8);
	p[2] = (v >> 16);
	p[3] = (v >> 24);
	p[4] = (v >> 32);
	p[5] = (v >> 40);
	p[6] = (v >> 48);
	p[7] = (v >> 56);
}

void write_le32(uint8_t *p, uint32_t v)
{
	p[0] = (v      );
	p[1] = (v >>  8);
	p[2] = (v >> 16);
	p[3] = (v >> 24);
}

void write_le16(uint8_t *p, uint16_t v)
{
	p[0] = (v      );
	p[1] = (v >>  8);
}


/* read functions, be */

uint64_t read_be64(const uint8_t *p)
{
	int i;
	uint64_t r = 0;

	for (i = 0; i < 8; i++)
		r |= p[i] << (7-i)*8;

	return r;
}

uint32_t read_be32(const uint8_t *p)
{
	return ((p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3]);
}

uint16_t read_be16(const uint8_t *p)
{
	return ((p[0] << 8) | p[1]);
}

/* read functions, le */

uint64_t read_le64(const uint8_t *p)
{
	int i;
	uint64_t r = 0;

	for (i = 0; i < 8; i++)
		r |= p[i] << i*8;

	return r;
}

uint32_t read_le32(const uint8_t *p)
{
	return ((p[3] << 24) | (p[2] << 16) | (p[1] << 8) | p[0]);
}

uint16_t read_le16(const uint8_t *p)
{
	return ((p[1] << 8) | p[0]);
}
